package com.xinda.itsm.mapper;

import java.util.List;
import com.xinda.itsm.domain.RepairOrder;

/**
 * 维修工单Mapper接口
 *
 * @author kerwincui
 * @date 2025-04-23
 */
public interface RepairOrderMapper
{
    /**
     * 查询维修工单
     *
     * @param id 维修工单主键
     * @return 维修工单
     */
    public RepairOrder selectRepairOrderById(Long id);

    /**
     * 查询维修工单列表
     *
     * @param repairOrder 维修工单
     * @return 维修工单集合
     */
    public List<RepairOrder> selectRepairOrderList(RepairOrder repairOrder);

    /**
     * 新增维修工单
     *
     * @param repairOrder 维修工单
     * @return 结果
     */
    public int insertRepairOrder(RepairOrder repairOrder);

    /**
     * 修改维修工单
     *
     * @param repairOrder 维修工单
     * @return 结果
     */
    public int updateRepairOrder(RepairOrder repairOrder);

    /**
     * 删除维修工单
     *
     * @param id 维修工单主键
     * @return 结果
     */
    public int deleteRepairOrderById(Long id);

    /**
     * 批量删除维修工单
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRepairOrderByIds(Long[] ids);
}
